Crate diatermi

Crate diatermi 

Re-exports

pub use draw::DrawCommunicator::DrawCommunicator;
pub use draw::DrawCommunicator::DrawHandler;
pub use draw::DrawTerminal::DrawTerminal;
pub use draw::Text::Text;
pub use terminal::run;
pub use terminal::CursorConfig;
pub use terminal::DrawObjectTrait;
pub use terminal::DrawTrait;
pub use terminal::Terminal;
pub use terminal::TerminalsEvents;
pub use terminal::Vector2;
pub use utils::*;
pub use Color::*;

Modules

draw
event
A module to read events.
terminal
utils

Macros

config
Configure an object and draw it
is_key_press
Executes the function if the key is pressed
is_key_press_event
Executes the function if it is pressed, otherwise if another function is supplied it will execute it
is_key_release
executes the function if the pressed key rises
is_key_release_event
executes the function if the pressed key rises or if you have another function it will execute it otherwise
is_key_repeat
Executes the function if the key is pressed repeatedly
is_key_repeat_event
It executes the function if a key is pressed repeatedly, otherwise if it was provided, the other function will be executed.
text
Create a text with the possible arguments:
vec2
Create a Vector2

Structs

DisableBracketedPaste
A command that disables bracketed paste mode.
DisableFocusChange
A command that disables focus event emission.
DisableMouseCapture
A command that disables mouse event capturing.
EnableBracketedPaste
A command that enables bracketed paste mode.
EnableFocusChange
A command that enables focus event emission.
EnableMouseCapture
A command that enables mouse event capturing.
KeyEvent
Represents a key event.
KeyEventState
Represents extra state about the key event.
KeyModifiers
Represents key modifiers (shift, control, alt, etc.).
KeyboardEnhancementFlags
Represents special flags that tell compatible terminals to add extra information to keyboard events.
MouseEvent
Represents a mouse event.
PopKeyboardEnhancementFlags
A command that disables extra kinds of keyboard events.
PushKeyboardEnhancementFlags
A command that enables the kitty keyboard protocol, which adds extra information to keyboard events and removes ambiguity for modifier keys.

Enums

Color
Represents a color.
Event
Represents an event.
KeyCode
Represents a key.
KeyEventKind
Represents a keyboard event kind.
MediaKeyCode
Represents a media key (as part of KeyCode::Media).
ModifierKeyCode
Represents a modifier key (as part of KeyCode::Modifier).
MouseButton
Represents a mouse button.
MouseEventKind
A mouse event kind.
SetCursorStyle
A command that sets the style of the cursor. It uses two types of escape codes, one to control blinking, and the other the shape.

Functions

poll
Checks if there is an Event available.
read
Reads a single Event.