Re-exports
pub use draw::DrawCommunicator::DrawCommunicator;pub use draw::DrawCommunicator::DrawHandler;pub use draw::DrawTerminal::DrawTerminal;pub use draw::Text::Text;pub use terminal::run;pub use terminal::CursorConfig;pub use terminal::DrawObjectTrait;pub use terminal::DrawTrait;pub use terminal::Terminal;pub use terminal::TerminalsEvents;pub use terminal::Vector2;pub use utils::*;pub use Color::*;
Modules
Macros
- config
- Configure an object and draw it
- is_
key_ press - Executes the function if the key is pressed
- is_
key_ press_ event - Executes the function if it is pressed, otherwise if another function is supplied it will execute it
- is_
key_ release - executes the function if the pressed key rises
- is_
key_ release_ event - executes the function if the pressed key rises or if you have another function it will execute it otherwise
- is_
key_ repeat - Executes the function if the key is pressed repeatedly
- is_
key_ repeat_ event - It executes the function if a key is pressed repeatedly, otherwise if it was provided, the other function will be executed.
- text
- Create a
textwith the possiblearguments: - vec2
- Create a
Vector2
Structs
- Disable
Bracketed Paste - A command that disables bracketed paste mode.
- Disable
Focus Change - A command that disables focus event emission.
- Disable
Mouse Capture - A command that disables mouse event capturing.
- Enable
Bracketed Paste - A command that enables bracketed paste mode.
- Enable
Focus Change - A command that enables focus event emission.
- Enable
Mouse Capture - A command that enables mouse event capturing.
- KeyEvent
- Represents a key event.
- KeyEvent
State - Represents extra state about the key event.
- KeyModifiers
- Represents key modifiers (shift, control, alt, etc.).
- Keyboard
Enhancement Flags - Represents special flags that tell compatible terminals to add extra information to keyboard events.
- Mouse
Event - Represents a mouse event.
- PopKeyboard
Enhancement Flags - A command that disables extra kinds of keyboard events.
- Push
Keyboard Enhancement Flags - A command that enables the kitty keyboard protocol, which adds extra information to keyboard events and removes ambiguity for modifier keys.
Enums
- Color
- Represents a color.
- Event
- Represents an event.
- KeyCode
- Represents a key.
- KeyEvent
Kind - Represents a keyboard event kind.
- Media
KeyCode - Represents a media key (as part of
KeyCode::Media). - Modifier
KeyCode - Represents a modifier key (as part of
KeyCode::Modifier). - Mouse
Button - Represents a mouse button.
- Mouse
Event Kind - A mouse event kind.
- SetCursor
Style - A command that sets the style of the cursor. It uses two types of escape codes, one to control blinking, and the other the shape.